@@ -31,14 +31,14 @@ from bakplane.utils import to_execution_statistics
 
 class JDBCStoreHelper(DataStoreHelper):
     def __init__(
-            self,
-            user: str,
-            password: str,
-            host: str,
-            port: int,
-            database: str,
-            schema_name: str,
-            driver: str
+        self,
+        user: str,
+        password: str,
+        host: str,
+        port: int,
+        database: str,
+        schema_name: str,
+        driver: str,
     ):
         self.metadata = MetaData()
         self.engine = create_engine(
@@ -47,10 +47,10 @@ class JDBCStoreHelper(DataStoreHelper):
         self.schema_name = schema_name
 
     def create_temporary_table(
-            self,
-            prefix: str,
-            columns: typing.List[Column],
-            rows: typing.List[typing.Dict[str, typing.Any]],
+        self,
+        prefix: str,
+        columns: typing.List[Column],
+        rows: typing.List[typing.Dict[str, typing.Any]],
     ) -> Table:
         tbl = Table(
             prefix
@@ -70,16 +70,16 @@ class JDBCStoreHelper(DataStoreHelper):
 
 
 def __build_read_all_query(
-        r: ReadAllRequest, res: ResolveResourcePathResponse
+    r: ReadAllRequest, res: ResolveResourcePathResponse
 ) -> str:
     return f'select {", ".join(r.columns)} from {res.context["schema_name"]}.{res.context["table_name"]}'
 
 
 def __build_read_query(
-        r: ReadRequest,
-        res: ResolveResourceIntentResponse,
-        dialect,
-        store_helper: DataStoreHelper,
+    r: ReadRequest,
+    res: ResolveResourceIntentResponse,
+    dialect,
+    store_helper: DataStoreHelper,
 ) -> str:
     from sqlalchemy import (
         Table,
@@ -197,19 +197,22 @@ def __build_read_query(
 
         res = (
             select(blocks.columns)
-                .select_from(blocks.selectable)
-                .where(and_(*blocks.constraints))
+            .select_from(blocks.selectable)
+            .where(and_(*blocks.constraints))
         )
 
     query = str(
-        res.compile(dialect=dialect, compile_kwargs={"literal_binds": True}, )
+        res.compile(
+            dialect=dialect,
+            compile_kwargs={"literal_binds": True},
+        )
     )
 
     return query
 
 
 def write_fn(
-        r: WriteRequest, res: ResolveResourcePathResponse, driver: str, url: str
+    r: WriteRequest, res: ResolveResourcePathResponse, driver: str, url: str
 ) -> WriteResponse:
     start = timer()
 
@@ -231,18 +234,18 @@ def write_fn(
 
 
 def __read_query(
-        spark, url: str, driver: str, query: str, user: str, password: str
+    spark, url: str, driver: str, query: str, user: str, password: str
 ):
     start = timer()
 
     df = (
         spark.read.format("jdbc")
-            .option("url", url)
-            .option("query", query)
-            .option("user", user)
-            .option("password", urllib.parse.unquote(password))
-            .option("driver", driver)
-            .load()
+        .option("url", url)
+        .option("query", query)
+        .option("user", user)
+        .option("password", urllib.parse.unquote(password))
+        .option("driver", driver)
+        .load()
     )
 
     end = timer()
@@ -250,16 +253,18 @@ def __read_query(
     return ReadResponse(
         df=df,
         execution_statistics=to_execution_statistics(start, end),
-        context={"query": query, },
+        context={
+            "query": query,
+        },
     )
 
 
 def read_all_fn(
-        ctx: typing.Any,
-        r: ReadAllRequest,
-        res: ResolveResourcePathResponse,
-        url: str,
-        driver: str,
+    ctx: typing.Any,
+    r: ReadAllRequest,
+    res: ResolveResourcePathResponse,
+    url: str,
+    driver: str,
 ) -> ReadResponse:
     return __read_query(
         spark=ctx,
@@ -272,13 +277,13 @@ def read_all_fn(
 
 
 def read_fn(
-        ctx: typing.Any,
-        r: ReadRequest,
-        res: ResolveResourceIntentResponse,
-        dialect,
-        url: str,
-        driver: str,
-        store_helper: DataStoreHelper,
+    ctx: typing.Any,
+    r: ReadRequest,
+    res: ResolveResourceIntentResponse,
+    dialect,
+    url: str,
+    driver: str,
+    store_helper: DataStoreHelper,
 ) -> ReadResponse:
     return __read_query(
         spark=ctx,
